@@ -12,11 +12,11 @@ class ResourceConstants:
         ERROR: str = "Error"
         COMPLETE: str = "Complete"
         DEPLOYING: str = "Deploying"
-        SCHEDULING_DISABLED = "Ready,SchedulingDisabled"
-        CRASH_LOOPBACK_OFF = "CrashLoopBackOff"
-        IMAGE_PULL_BACK_OFF = "ImagePullBackOff"
-        ERR_IMAGE_PULL = "ErrImagePull"
-        ACTIVE = "Active"
+        SCHEDULING_DISABLED: str = "Ready,SchedulingDisabled"
+        CRASH_LOOPBACK_OFF: str = "CrashLoopBackOff"
+        IMAGE_PULL_BACK_OFF: str = "ImagePullBackOff"
+        ERR_IMAGE_PULL: str = "ErrImagePull"
+        ACTIVE: str = "Active"
 
     class Condition:
         UPGRADEABLE: str = "Upgradeable"
@@ -27,7 +27,9 @@ class ResourceConstants:
         RECONCILE_COMPLETE: str = "ReconcileComplete"
         READY: str = "Ready"
         FAILING: str = "Failing"
-        NETWORK_READY = "NetworkReady"
+        NETWORK_READY: str = "NetworkReady"
+        ARCHIVED: str = "Archived"
+        CANCELED: str = "Canceled"
 
         class Status:
             TRUE: str = "True"
@@ -52,9 +54,9 @@ class ResourceConstants:
             SUCCEEDED: str = "Succeeded"
 
     class Type:
-        CLUSTER_IP = "ClusterIP"
-        NODE_PORT = "NodePort"
-        LOAD_BALANCER = "LoadBalancer"
+        CLUSTER_IP: str = "ClusterIP"
+        NODE_PORT: str = "NodePort"
+        LOAD_BALANCER: str = "LoadBalancer"
 
     class Interface:
         class State:
@@ -63,7 +65,7 @@ class ResourceConstants:
             ABSENT: str = "absent"
 
     class ProviderType:
-        VSPHERE = "vsphere"
-        OPENSHIFT = "openshift"
-        RHV = "ovirt"
-        OVA = "ova"
+        VSPHERE: str = "vsphere"
+        OPENSHIFT: str = "openshift"
+        RHV: str = "ovirt"
+        OVA: str = "ova"
